==> cantata_1.3.4.ds1.orig.tar.xz: cantata-1.3.4/widgets/coverwidget.h <==
/*
 * Cantata
 *
 * Copyright (c) 2011-2014 Craig Drummond <craig.p.drummond@gmail.com>
 *
 * ----
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef COVERWIDGET_H
#define COVERWIDGET_H

#include <QLabel>
#include <QImage>
#include "song.h"

class QPixmap;

class CoverWidget : public QLabel
{
    Q_OBJECT

public:
    static const int constBorder;

    CoverWidget(QWidget *p);
    virtual ~CoverWidget();

    void update(const Song &s);
    const Song & song() const { return current; }
    bool isEmpty() const { return empty; }
    bool isValid() const { return !empty && valid; }
    const QString & fileName() const { return coverFileName; }
    const QImage &image() const { return img; }

Q_SIGNALS:
    // coverImage /might/ contain the default images, if no cover was found
    void coverImage(const QImage &img);
    // albumCover will only ever contain a valid cover, or a null image
    void albumCover(const QImage &img);
    void coverFile(const QString &name);
    void clicked();

private Q_SLOTS:
    void init();
    void coverRetrieved(const Song &s, const QImage &img, const QString &file);

private:
    const QPixmap & stdPixmap(bool stream);
    void update(const QImage &i);
    void update(const QPixmap &pix);
    bool event(QEvent *event);
    void resizeEvent(QResizeEvent *e);
//     void paintEvent(QPaintEvent *e);
    #ifndef Q_OS_WIN
    void initIconThemes();
    QString findIcon(const QStringList &names);
    #endif

private:
    bool empty;
    bool valid;
    bool pressed;
    Song current;
    QString tipText;
    mutable QImage img;
//     mutable QPixmap bgnd;
    QString coverFileName;
    QPixmap noStreamCover;
    QPixmap noCover;
    QString noStreamCoverFileName;
    QString noCoverFileName;
    #ifndef Q_OS_WIN
    QStringList iconThemes;
    #endif
};

#endif

==> cantata_2.3.3.ds1.orig.tar.xz: cantata-2.3.3/widgets/coverwidget.h <==
/*
 * Cantata
 *
 * Copyright (c) 2011-2018 Craig Drummond <craig.p.drummond@gmail.com>
 *
 * ----
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef COVERWIDGET_H
#define COVERWIDGET_H

#include <QWidget>
#include <QLabel>

class CoverLabel : public QLabel
{
    Q_OBJECT
public:
    CoverLabel(QWidget *p);

    void updateToolTip(bool isEvent);
    bool event(QEvent *event) override;
    void paintEvent(QPaintEvent *) override;
    void updatePix();
    void deletePix();

private:
    QPoint lastTtPos;
    bool pressed;
    QPixmap pix;
};

class CoverWidget : public QWidget
{
    Q_OBJECT

public:
    CoverWidget(QWidget *p);
    ~CoverWidget() override;

    void setSize(int min);
    void setEnabled(bool e);

    void emitClicked() { emit clicked(); }

Q_SIGNALS:
    void clicked();

private Q_SLOTS:
    void coverImage(const QImage &);

private:
    CoverLabel *label;
};

#endif
